import { Component, ViewChild, OnDestroy, OnInit, Type } from '@angular/core';
import { Router } from '@angular/router';

import { MatTabChangeEvent } from '@angular/material/tabs';
import { MatSidenav } from '@angular/material/sidenav';

import { Store, select } from '@ngrx/store';

import { AppSelector } from '@app/store/state';
import { Subscription } from 'rxjs';

@Component({
  selector: 'app-layouts-default',
  templateUrl: './default.layout.component.html',
  styleUrls: ['./default.layout.component.scss']
})
export class DefaultLayoutComponent implements OnInit, OnDestroy {
  @ViewChild('leftSidenav', { static: true })
  leftSidenav: MatSidenav;

  leftSectionComponent: Type<any>;
  contentSectionComponent: Type<any>;

  private windowSizeSubscription: Subscription;

  constructor(private router: Router, private store: Store<any>) {}

  ngOnInit(): void {
    this.windowSizeSubscription = this.store
      .pipe(select(AppSelector.windowSize))
      .subscribe((size) => {
        if (size.width < 780) {
          if (this.leftSidenav.opened) {
            this.leftSidenav.close();
          }
        } else {
          if (!this.leftSidenav.opened) {
            this.leftSidenav.open();
          }
        }
      });
  }

  ngOnDestroy(): void {
    if (!this.windowSizeSubscription) {
      this.windowSizeSubscription.unsubscribe();
    }
  }

  onSelectedTabChange(event: MatTabChangeEvent) {
    switch (event.index) {
      case 1:
        // this.router.navigate(['/chat']);
        break;
      case 2:
        import('@app/sections/organization/organization.section.module').then(
          (m) => {
            this.leftSectionComponent = m.TreeListSectionComponent;
          }
        );
        import('@app/sections/organization/organization.section.module').then(
          (m) => {
            this.contentSectionComponent = m.MembersSectionComponent;
          }
        );
        break;
      case 3:
        // this.router.navigate(['/message']);
        break;
      default:
        // this.router.navigate(['/group']);
        break;
    }
  }

  onClickToggleLeftSidenav() {
    if (this.leftSidenav.opened) {
      this.leftSidenav.close();
    } else {
      this.leftSidenav.open();
    }
  }
}
